@@ -202,6 +202,7 @@ char *getcrashfilename()
 	    break;
 	 }
       }
+      fclose(fi);
    }
    return retstr;
 }
@@ -232,13 +233,16 @@ void findcrashfiles()
    struct stat sbuf;
    uid_t userid = getuid();
    time_t recent = 0;
+   char *snptr;
+   int pid;
 
    cwd = opendir(xobjs.tempdir);
    if (cwd == NULL) return;	/* No tmp directory, no tmp files! */
 
    while ((dp = readdir(cwd)) != NULL) {
       sprintf(_STR, "%s/%s", xobjs.tempdir, dp->d_name);
-      if (!strncmp(_STR + strlen(xobjs.tempdir) + 1, "XC", 2)) {
+      snptr = _STR + strlen(xobjs.tempdir) + 1;
+      if (!strncmp(snptr, "XC", 2)) {
          if ((!stat(_STR, &sbuf)) && (sbuf.st_uid == userid)) {
 	    if ((recent == 0) || (sbuf.st_ctime > recent)) {
 	       recent = sbuf.st_ctime;
@@ -258,12 +262,14 @@ void findcrashfiles()
 
 #ifdef TCL_WRAPPER
       char *cfile = getcrashfilename();
+
       sprintf(_STR, ".query.title.field configure -text "
 		"\"Recover file \'%s\'?\"", 
 		(cfile == NULL) ? "(unknown)" : cfile);
       Tcl_Eval(xcinterp, _STR);
       Tcl_Eval(xcinterp, ".query.bbar.okay configure -command "
 		"{filerecover; wm withdraw .query}; wm deiconify .query");
+      if (cfile != NULL) free(cfile);
 #else
       getfile(NULL, (pointertype)RECOVER, NULL);   /* Crash recovery mode */
 #endif
@@ -792,11 +798,11 @@ void genfilelist(xcWidget parent, popupstruct *okaystruct, Dimension width)
 /* Look for a directory name in a string and update cwdname accordingly	   */
 /*-------------------------------------------------------------------------*/
 
-int lookdirectory(char *lstring)
+int lookdirectory(char *lstring, int nchars)
 {
    int slen;
 
-   xc_tilde_expand(lstring);
+   xc_tilde_expand(lstring, nchars);
    slen = strlen(lstring);
 
    if (lstring[slen - 1] == '/' || (opendir(lstring) != NULL)) {
