@@ -130,6 +130,9 @@ void transform_graphic(graphicptr gp)
 
     scale = gp->scale * UTopTransScale(1.0);
 
+    if (gp->rotation == 360) gp->rotation = 0;
+    else if (gp->rotation < 0) gp->rotation += 360;
+
     cosr = cos(RADFAC * gp->rotation);
     sinr = sin(RADFAC * gp->rotation);
     c = (int)(8192 * cosr / scale);
@@ -159,6 +162,12 @@ void transform_graphic(graphicptr gp)
 			0, 0, twidth, theight, 8, 0);
     gp->target->data = (char *)calloc(theight, gp->target->bytes_per_line);
 
+    if (gp->target->data == (char *)NULL) {
+       XDestroyImage(gp->target);
+       gp->clipmask = (Pixmap)NULL;
+       gp->valid = FALSE;
+    }
+
     if (gp->rotation != 0) {
        gp->clipmask = XCreatePixmap(dpy, areastruct.areawin, twidth, theight, 1);
        if (cmgc == (GC)NULL) {
@@ -205,6 +214,7 @@ void UDrawGraphic(graphicptr gp)
     int width, height;
 
     if (gp->valid == FALSE) transform_graphic(gp);
+    if (gp->valid == FALSE) return;			/* Error condition */
 
     user_to_window(gp->position, &ppt);
 
@@ -217,7 +227,8 @@ void UDrawGraphic(graphicptr gp)
     }
 
     XPutImage(dpy, areastruct.areawin, areastruct.gc,
-		gp->target, 0, 0, ppt.x, ppt.y, gp->target->width, gp->target->height);
+		gp->target, 0, 0, ppt.x, ppt.y, gp->target->width,
+		gp->target->height);
 
     if (gp->clipmask != (Pixmap)NULL)
        XSetClipMask(dpy, areastruct.gc, None);
