@@ -151,8 +151,10 @@ short pagelinks(int page)
    for (i = 0; i < xobjs.pages; i++)
       if (xobjs.pagelist[i]->pageinst != NULL)
 	 if (xobjs.pagelist[i]->pageinst->thisobject->parts > 0)
-	    if ((i == page) || (!strcmp(xobjs.pagelist[i]->filename,
-			xobjs.pagelist[page]->filename)))
+	    if ((i == page) || (xobjs.pagelist[i]->filename &&
+			xobjs.pagelist[page]->filename &&
+			(!strcmp(xobjs.pagelist[i]->filename,
+			xobjs.pagelist[page]->filename))))
 	       count++;
 
    return count;
@@ -212,9 +214,11 @@ short *pagetotals(int page, short mode)
 		  (*(counts + i)) = 1;
 	       else
 	       {
-	          if ((i == page) || (!strcmp(xobjs.pagelist[i]->filename,
-			xobjs.pagelist[page]->filename)))
-	             if (*(counts + i) == 0)
+	          if ((i == page) || (xobjs.pagelist[i]->filename
+			&& xobjs.pagelist[page]->filename
+			&& (!strcmp(xobjs.pagelist[i]->filename,
+			xobjs.pagelist[page]->filename))))
+		     if ((mode == INDEPENDENT) || (*(counts + i) == 0))
 		        (*(icount + i))++;
 	       }
 	    }
