@@ -222,7 +222,7 @@ extern void fileselect(xcWidget, popupstruct *, XButtonEvent *);
 extern void showlscroll(xcWidget, caddr_t, caddr_t);
 extern void draglscroll(xcWidget, popupstruct *, XButtonEvent *);
 extern void genfilelist(xcWidget, popupstruct *, Dimension);
-extern int lookdirectory(char *);
+extern int lookdirectory(char *, int);
 
 /* from files.c: */
 
@@ -254,10 +254,10 @@ extern void loadulib();
 extern void loadblib();
 extern void getlib(xcWidget, caddr_t, caddr_t);
 extern void getuserlib(xcWidget, caddr_t, caddr_t);
-extern void loadlibrary(short);
+extern Boolean loadlibrary(short);
 extern void startloadfile();
 extern void importfile();
-extern void loadfile(short);
+extern Boolean loadfile(short, int);
 extern void readlabel(objectptr, char *, stringpart **);
 extern void readparams(objectptr, objinstptr, objectptr, char *);
 extern u_char *find_match(u_char *);
@@ -287,7 +287,9 @@ extern void findfonts(objectptr, short *);
 extern void savefile(short);
 extern int printRGBvalues(char *, int, const char *);
 extern char *nosprint(char *);
-extern Boolean xc_tilde_expand(char *);
+extern FILE *fileopen(char *, char *, char *, int);
+extern Boolean xc_tilde_expand(char *, int);
+extern Boolean xc_variable_expand(char *, int);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
 extern int writelabelsegs(FILE *, short *, stringpart *);
@@ -581,6 +583,9 @@ extern void gennetlist(objinstptr);
 extern void gencalls(objectptr);
 extern void search_on_siblings(objinstptr, objinstptr, pushlistptr,
 		short, short, short, short);
+extern char *GetHierarchy(pushlistptr *, Boolean);
+extern Boolean HierNameToObject(objinstptr, char *, pushlistptr *);
+extern void resolve_devindex(objectptr, Boolean);
 extern void copy_bus(Genericlist *, Genericlist *);
 extern Genericlist *is_resolved(genericptr *, pushlistptr, objectptr *);
 extern Boolean highlightnet(objectptr, objinstptr, int, u_char);
@@ -610,11 +615,12 @@ extern void resolve_devnames(objectptr);
 extern void resolve_indices(objectptr, Boolean);
 extern void clear_indices(objectptr);
 extern void unnumber(objectptr);
-extern char *parseinfo(objectptr, CalllistPtr, char *, char *, Boolean);
+extern char *parseinfo(objectptr, objectptr, CalllistPtr, char *, char *, Boolean,
+		Boolean);
 extern int writedevice(FILE *, char *, objectptr, CalllistPtr, char *);
 extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
-extern void writehierarchy(objectptr, CalllistPtr, FILE *, char *);
+extern void writehierarchy(objectptr, objinstptr, CalllistPtr, FILE *, char *);
 extern void writenet(objectptr, char *, char *);
 extern Boolean writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
 extern void outputpcb(struct Ptab *, FILE *);
@@ -840,8 +846,9 @@ extern void popupprompt(xcWidget, char *, char *, void (*function)(),
 extern void getproptext(xcWidget, propstruct *, caddr_t);
 extern int rgb_alloccolor(int, int, int);
 extern void addtocolorlist(xcWidget, int);
-extern void addnewcolorentry(int);
+extern int addnewcolorentry(int);
 extern int xc_getlayoutcolor(int);
+extern int query_named_color(char *);
 extern void outputpopup(xcWidget, caddr_t, caddr_t);
 extern void docommand();
 extern void W1printf(char *);
@@ -851,6 +858,7 @@ extern int xc_alloccolor(char *);
 extern void dointr(int);
 extern void DoNothing(xcWidget, caddr_t, caddr_t);
 extern u_short countchanges(char **);
+extern u_short getchanges(objectptr);
 extern void quitcheck(xcWidget, caddr_t, caddr_t);
 extern void quit(xcWidget, caddr_t);
 extern void resizetoolbar();
